<?php

/**
 * @file
 * Hooks related to the Localized Configuration system.
 */

/**
 * Allows changing the list of languages available to Localized Config.
 *
 * @param \Drupal\Core\Language\LanguageInterface[] $languages
 *   Array of languages, keyed by langcode.
 */
function hook_localized_config_language_list_alter(array &$languages) {
  // Always remove English.
  unset($languages['en']);
}

/**
 * Allows changing which languages a user identifies with.
 *
 * @param \Drupal\Core\Language\LanguageInterface[] $languages
 *   Array of languages, keyed by langcode.
 * @param \Drupal\user\UserInterface $user
 *   The user object.
 */
function hook_localized_config_user_languages_alter(array &$languages, \Drupal\user\UserInterface $user) {
  if ($user->id() === 1) {
    $languages = \Drupal::service('localized_config.language_helper')->getFilteredLanguages();
  }
  elseif ($user->hasField('field_language')) {
    foreach ($user->get('field_language') as $item) {
      /** @var \Drupal\language\ConfigurableLanguageInterface $language */
      $language = $item->entity;
      $languages[$language->getId()] = $language;
    }
  }
}
